@@ -8,9 +8,11 @@
         and thus help debugging in pycatia.
         
 """
+from typing import Iterator
+
 from pycatia.sketcher_interfaces.geometric_element import GeometricElement
 from pycatia.system_interfaces.collection import Collection
-from pycatia.types import cat_variant
+from pycatia.types.general import cat_variant
 
 
 class GeometricElements(Collection):
@@ -85,5 +87,9 @@ class GeometricElements(Collection):
 
         return GeometricElement(self.geometric_elements.item(n + 1))
 
+    def __iter__(self) -> Iterator[GeometricElement]:
+        for i in range(self.count):
+            yield self.child_object(self.com_object.item(i + 1))
+
     def __repr__(self):
         return f'GeometricElements(name="{self.name}")'
