@@ -8,9 +8,11 @@
         and thus help debugging in pycatia.
         
 """
+from typing import Iterator
+
 from pycatia.space_analyses_interfaces.section import Section
 from pycatia.system_interfaces.collection import Collection
-from pycatia.types import cat_variant
+from pycatia.types.general import cat_variant
 
 
 class Sections(Collection):
@@ -175,5 +177,9 @@ class Sections(Collection):
 
         return Section(self.sections.item(n + 1))
 
+    def __iter__(self) -> Iterator[Section]:
+        for i in range(self.count):
+            yield self.child_object(self.com_object.item(i + 1))
+
     def __repr__(self):
         return f'Sections(name="{self.name}")'
