@@ -8,7 +8,7 @@
         and thus help debugging in pycatia.
 
 """
-
+from typing import Iterator
 from typing import TYPE_CHECKING
 
 from pycatia.base_interfaces.pycatia import PyCATIA
@@ -226,10 +226,14 @@ class Collection(PyCATIA):
         return self.count
 
     def __getitem__(self, n: int) -> AnyObject:
-
         if (n + 1) > self.count:
             raise StopIteration
-        return self.child_object(self.com_object.item(n + 1))
+
+        return AnyObject(self.com_object.item(n + 1))
+
+    def __iter__(self) -> Iterator[AnyObject]:
+        for i in range(self.count):
+            yield self.child_object(self.com_object.item(i + 1))
 
     def __repr__(self):
         return f'Collection(name="{self.name}")'
